@@ -15,15 +15,16 @@ from .templates import render_template
 class Email:
     def __init__(
         self,
-        subject: str,
+        default_subject: str,
         template_path: str,
     ) -> None:
-        self.subject = subject
+        self.default_subject = default_subject
         self.template_path = template_path
 
     def send(
         self,
         context: Dict[str, Any],
+        subject: Optional[str] = None,
         to: Optional[List[str]] = None,
         cc: Optional[List[str]] = None,
         bcc: Optional[List[str]] = None,
@@ -36,8 +37,10 @@ class Email:
         if not to and not cc and not bcc:
             return
         email = EmailMessage(
-            subject=self.subject,
+            subject=subject or self.default_subject,
             body=render_template(self.template_path, context),
+            to=to,
+            cc=cc,
             bcc=bcc,
             from_email=from_email or settings.DEFAULT_FROM_EMAIL,
         )
@@ -47,7 +50,13 @@ class Email:
     def send_async(
         self,
         context: Dict[str, Any],
-        bcc: List[str],
+        subject: Optional[str] = None,
+        to: Optional[List[str]] = None,
+        cc: Optional[List[str]] = None,
+        bcc: Optional[List[str]] = None,
+        from_email: Optional[str] = None,
     ) -> None:
-        thread = Thread(target=self.send, args=(context, bcc))
+        thread = Thread(
+            target=self.send, args=(context, subject, to, cc, bcc, from_email)
+        )
         thread.start()
