@@ -1,4 +1,4 @@
-"""Functions for interacting with django settings"""
+"""Functions for interacting with django settings."""
 
 # Built-in
 from typing import Any
@@ -8,5 +8,6 @@ from django.conf import settings
 
 
 def get_config(key: str, default: Any = None) -> Any:
-    """Tries to get the data from django settings, or returns the default value"""
+    """Tries to get the data from django settings, or returns the default
+    value."""
     return getattr(settings, key, default)
