@@ -1,4 +1,4 @@
-"""Utility functions for the numpy library"""
+"""Utility functions for the numpy library."""
 
 # Built-in
 from typing import Any, List
@@ -8,7 +8,8 @@ import numpy as np
 
 
 def get_unique_from_numpy(arr: np.ndarray) -> List[Any]:
-    """Returns the unique values from a numpy array while keeping its original order"""
+    """Returns the unique values from a numpy array while keeping its original
+    order."""
     unique_index = np.unique(arr, return_index=True)[1]
     unique_index.sort()
     unique_values = [arr[index] for index in unique_index]
