@@ -1,4 +1,4 @@
-"""Utility functions for working with JSON files"""
+"""Utility functions for working with JSON files."""
 
 # Built-in
 import json
@@ -6,7 +6,7 @@ import os
 
 
 def sort_json(path: str) -> None:
-    """Overwrites and sorts a JSON file to make it cleaner / more readable"""
+    """Overwrites and sorts a JSON file to make it cleaner / more readable."""
     ext = os.path.splitext(path)[1]
     if ext != ".json":
         raise TypeError("The 'path' must lead to a JSON file")
